@@ -1,8 +1,6 @@
 from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 
-from ..models.courses import Course
-from ..models.events import Event
 from ..models.roles import Leader
 from ..models.schoolyear import SchoolYear
 from ..models.subjects import Subject, SubjectGroup, SubjectType
@@ -12,7 +10,7 @@ class SchoolYearListFilter(admin.FieldListFilter):
     def __init__(self, field, request, params, model, model_admin, field_path):
         try:
             request.school_year = SchoolYear.objects.get(year=params['year'])
-        except:
+        except (SchoolYear.DoesNotExist, ValueError, KeyError):
             pass
         self.school_year = request.school_year
         super(SchoolYearListFilter, self).__init__(field, request, params, model, model_admin, field_path)
@@ -34,6 +32,37 @@ class SchoolYearListFilter(admin.FieldListFilter):
         return queryset.filter(**{self.field_path: self.school_year})
 
 
+class ActiveListFilter(admin.SimpleListFilter):
+    title = _('status')
+    parameter_name = 'status'
+
+    def lookups(self, request, model_admin):
+        return (
+            (None, _('active')),
+            ('inactive', _('inactive')),
+        )
+
+    def queryset(self, request, queryset):
+        if self.value() == 'inactive':
+            return queryset.filter(active=False)
+        else:
+            return queryset.filter(active=True)
+
+    def choices(self, cl):
+        value = self.value()
+        return [
+            {
+                'selected': value != 'inactive',
+                'query_string': cl.get_query_string({}, [self.parameter_name]),
+                'display': _('active'),
+            },
+            {
+                'selected': value == 'inactive',
+                'query_string': cl.get_query_string({self.parameter_name: 'inactive'}),
+                'display': _('inactive'),
+            },
+        ]
+
 
 class ApprovedListFilter(admin.SimpleListFilter):
     title = _('approval')
@@ -52,7 +81,6 @@ class ApprovedListFilter(admin.SimpleListFilter):
             return queryset.filter(approved__isnull=True)
 
 
-
 class CanceledListFilter(admin.SimpleListFilter):
     title = _('cancelation')
     parameter_name = 'canceled'
@@ -85,41 +113,28 @@ class CanceledListFilter(admin.SimpleListFilter):
         ]
 
 
-
 class SubjectTypeListFilter(admin.RelatedFieldListFilter):
-    subject_type_type = None
-
     def __init__(self, field, request, params, model, model_admin, field_path):
         self.subject_types = SubjectType.objects.all()
-        if self.subject_type_type:
-            self.title = SubjectType.subject_type_type_labels[self.subject_type_type]
-            self.subject_types = self.subject_types.filter(subject_type=self.subject_type_type)
+        subject_type_type = getattr(model_admin, 'subject_type_type', None)
+        if subject_type_type:
+            self.subject_types = self.subject_types.filter(subject_type=subject_type_type)
         super(SubjectTypeListFilter, self).__init__(field, request, params, model, model_admin, field_path)
-        if self.subject_type_type:
-            self.title = SubjectType.subject_type_type_labels[self.subject_type_type]
+        if subject_type_type:
+            self.title = SubjectType.subject_type_type_labels[subject_type_type]
         request.leprikon_subject_type_id = self.lookup_val
 
     def field_choices(self, field, request, model_admin):
         return [(t.id, t.plural) for t in self.subject_types.all()]
 
 
-class CourseTypeListFilter(SubjectTypeListFilter):
-    subject_type_type = SubjectType.COURSE
-
-
-class EventTypeListFilter(SubjectTypeListFilter):
-    subject_type_type = SubjectType.EVENT
-
-
-
 class SubjectGroupListFilter(admin.RelatedFieldListFilter):
-    subject_type_type = None
-
     def __init__(self, field, request, params, model, model_admin, field_path):
+        subject_type_type = getattr(model_admin, 'subject_type_type', None)
         if hasattr(request, 'leprikon_subject_type_id') and request.leprikon_subject_type_id:
             self.groups = SubjectGroup.objects.filter(subject_types__id=request.leprikon_subject_type_id)
-        elif self.subject_type_type:
-            self.groups = SubjectGroup.objects.filter(subject_types__subject_type=self.subject_type_type)
+        elif subject_type_type:
+            self.groups = SubjectGroup.objects.filter(subject_types__subject_type=subject_type_type)
         else:
             self.groups = SubjectGroup.objects.all()
         super(SubjectGroupListFilter, self).__init__(field, request, params, model, model_admin, field_path)
@@ -129,46 +144,26 @@ class SubjectGroupListFilter(admin.RelatedFieldListFilter):
         return [(g.id, g.plural) for g in self.groups.distinct()]
 
 
-class CourseGroupListFilter(SubjectGroupListFilter):
-    subject_type_type = SubjectType.COURSE
-
-
-class EventGroupListFilter(SubjectGroupListFilter):
-    subject_type_type = SubjectType.EVENT
-
-
-
 class SubjectListFilter(admin.RelatedFieldListFilter):
-    subject_type_type = None
     model = Subject
 
     def __init__(self, field, request, params, model, model_admin, field_path):
         self.subjects = self.model.objects.filter(school_year=request.school_year)
+        subject_type_type = getattr(model_admin, 'subject_type_type', None)
         if hasattr(request, 'leprikon_subject_type_id') and request.leprikon_subject_type_id:
             self.subjects = self.subjects.filter(subject_type__id=request.leprikon_subject_type_id)
-        elif self.subject_type_type:
-            self.subjects = self.subjects.filter(subject_type__subject_type=self.subject_type_type)
+        elif subject_type_type:
+            self.subjects = self.subjects.filter(subject_type__subject_type=subject_type_type)
         if hasattr(request, 'leprikon_subject_group_id') and request.leprikon_subject_group_id:
             self.subjects = self.subjects.filter(subject_group__id=request.leprikon_subject_group_id)
         super(SubjectListFilter, self).__init__(field, request, params, model, model_admin, field_path)
-        if self.subject_type_type:
-            self.title = SubjectType.subject_type_labels[self.subject_type_type]
+        if subject_type_type:
+            self.title = SubjectType.subject_type_labels[subject_type_type]
 
     def field_choices(self, field, request, model_admin):
         return [(s.id, s.name) for s in self.subjects]
 
 
-class CourseListFilter(SubjectListFilter):
-    subject_type_type = SubjectType.COURSE
-    model = Course
-
-
-class EventListFilter(SubjectListFilter):
-    subject_type_type = SubjectType.EVENT
-    model = Event
-
-
-
 class LeaderListFilter(admin.RelatedFieldListFilter):
     def __init__(self, field, request, params, model, model_admin, field_path):
         self.leaders = Leader.objects.filter(school_years=request.school_year)
@@ -176,3 +171,31 @@ class LeaderListFilter(admin.RelatedFieldListFilter):
 
     def field_choices(self, field, request, model_admin):
         return [(leader.id, leader) for leader in self.leaders]
+
+
+class IsNullFieldListFilter(admin.FieldListFilter):
+    def __init__(self, field, request, params, model, model_admin, field_path):
+        self.lookup_kwarg = '%s__isnull' % field_path
+        self.lookup_val = request.GET.get(self.lookup_kwarg)
+        if not hasattr(field, 'verbose_name') and hasattr(field, 'related_model'):
+            field.verbose_name = field.related_model._meta.verbose_name
+        super().__init__(field, request, params, model, model_admin, field_path)
+        if (self.used_parameters and self.lookup_kwarg in self.used_parameters and
+                self.used_parameters[self.lookup_kwarg] in ('1', '0')):
+            self.used_parameters[self.lookup_kwarg] = bool(int(self.used_parameters[self.lookup_kwarg]))
+
+    def expected_parameters(self):
+        return [self.lookup_kwarg]
+
+    def choices(self, changelist):
+        for lookup, title in (
+                (None, _('All')),
+                ('0', _('Set')),
+                ('1', _('Not set'))):
+            yield {
+                'selected': self.lookup_val == lookup,
+                'query_string': changelist.get_query_string({
+                    self.lookup_kwarg: lookup,
+                }),
+                'display': title,
+            }
