@@ -1,4 +1,5 @@
 from bankreader.models import Transaction as BankreaderTransaction
+from django import forms
 from django.conf.urls import url as urls_url
 from django.contrib import admin, messages
 from django.contrib.admin.templatetags.admin_list import _boolean_icon
@@ -109,6 +110,7 @@ class SubjectBaseAdmin(AdminExportMixin, BulkUpdateMixin, SendMessageAdminMixin,
         ('subject_type', SubjectTypeListFilter),
         ('groups', SubjectGroupListFilter),
         ('leaders', LeaderListFilter),
+        'place',
     )
     inlines = (
         SubjectVariantInlineAdmin,
@@ -419,6 +421,7 @@ class RegistrationBillingInfoInlineAdmin(admin.TabularInline):
 
 
 class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMessageAdminMixin, admin.ModelAdmin):
+    form = RegistrationAdminForm
     inlines = (RegistrationBillingInfoInlineAdmin,)
     list_editable = ('note',)
     list_export = (
@@ -458,8 +461,10 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMessageAdminMixin, admi
         CanceledListFilter,
         'registration_link',
         ('billing_info', IsNullFieldListFilter),
+        'subject__groups',
         ('subject', SubjectListFilter),
         ('subject__leaders', LeaderListFilter),
+        'subject__place',
     )
     actions = ('approve', 'refuse', 'request_payment', 'cancel')
     search_fields = (
@@ -504,7 +509,13 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMessageAdminMixin, admi
         return ChangeList
 
     def get_queryset(self, request):
-        return super().get_queryset(request).annotate(random_number=Random())
+        return super().get_queryset(request).prefetch_related(
+            'discounts',
+            'payments',
+        ).select_related(
+            'subject',
+            'user',
+        ).annotate(random_number=Random())
 
     def approve(self, request, queryset):
         for registration in queryset.all():
@@ -582,11 +593,12 @@ class SubjectRegistrationBaseAdmin(AdminExportMixin, SendMessageAdminMixin, admi
 
         if request.subject:
             kwargs['form'] = type(
-                RegistrationAdminForm.__name__,
-                (RegistrationAdminForm,),
+                self.form.__name__,
+                (self.form,),
                 {'subject': request.subject},
             )
         else:
+            kwargs['form'] = forms.ModelForm
             kwargs['fields'] = ['subject']
         return super(SubjectRegistrationBaseAdmin, self).get_form(request, obj, **kwargs)
 
@@ -757,7 +769,7 @@ class SubjectPaymentBaseAdmin(AdminExportMixin, admin.ModelAdmin):
         if self.is_closed(request, obj):
             return False
         else:
-            return super(SubjectPaymentBaseAdmin, self).has_delete_permission(request, obj)
+            return super().has_delete_permission(request, obj)
 
     def get_readonly_fields(self, request, obj=None):
         if obj:
@@ -770,9 +782,16 @@ class SubjectPaymentBaseAdmin(AdminExportMixin, admin.ModelAdmin):
             return ()
 
     def get_actions(self, request):
-        actions = super(SubjectPaymentBaseAdmin, self).get_actions(request)
+        actions = super().get_actions(request)
         if 'delete_selected' in actions:
-            del(actions['delete_selected'])
+            def delete_selected(model_admin, request, queryset):
+                if request.leprikon_site.max_closure_date:
+                    queryset = queryset.filter(accounted__date__gt=request.leprikon_site.max_closure_date)
+                return admin.actions.delete_selected(model_admin, request, queryset)
+            actions['delete_selected'] = (
+                delete_selected,
+                *actions['delete_selected'][1:]
+            )
         return actions
 
     def subject(self, obj):
