@@ -7,7 +7,7 @@ from .form import FormMixin
 class ParentForm(FormMixin, forms.ModelForm):
 
     def __init__(self, user, *args, **kwargs):
-        super(ParentForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.instance.user = user
 
     class Meta:
