@@ -1,6 +1,7 @@
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 
+from ...models.events import Event
 from ..form import GetFormMixin
 
 
@@ -15,4 +16,13 @@ class EventPaymentsStatusForm(GetFormMixin, forms.Form):
 
 class EventStatsForm(GetFormMixin, forms.Form):
     date = forms.DateField(label=_('Statistics for date'))
+    events = forms.ModelMultipleChoiceField(
+        queryset=Event.objects.all(),
+        label=_('Events'),
+    )
     paid_only = forms.BooleanField(label=_('Count only paid registrations'), required=False)
+
+    def __init__(self, *args, **kwargs):
+        school_year = kwargs.pop('school_year')
+        super().__init__(*args, **kwargs)
+        self.fields['events'].queryset = Event.objects.filter(school_year=school_year)
