@@ -100,35 +100,29 @@ class EventRegistration(SubjectRegistration):
         verbose_name = _('event registration')
         verbose_name_plural = _('event registrations')
 
-    def get_due_from(self):
-        return self.subject.event.due_from
-
     def get_payment_status(self, d=None):
-        if d is None:
-            d = date.today()
-        explanation = ',\n'.join(
-            discount.explanation.strip()
-            for discount in self.all_discounts
-            if discount.accounted.date() <= d and discount.explanation.strip()
-        )
         return PaymentStatus(
             price=self.price,
             discount=self.get_discounted(d),
-            explanation=explanation,
+            explanation=',\n'.join(
+                discount.explanation.strip()
+                for discount in self.all_discounts
+                if (d is None or discount.accounted.date() <= d) and discount.explanation.strip()
+            ),
             paid=self.get_paid(d),
-            current_date=d,
-            due_from=self.payment_requested and max(self.subject.event.due_from, self.payment_requested.date()),
-            due_date=self.subject.event.due_date,
+            current_date=d or date.today(),
+            due_from=self.approved and max(
+                self.subject.event.due_from,
+                self.approved.date(),
+            ),
+            due_date=self.approved and max(
+                self.subject.event.due_date,
+                self.approved.date() + timedelta(
+                    days=self.subject.min_due_date_days
+                )
+            ),
         )
 
-    @cached_property
-    def payment_status(self):
-        return self.get_payment_status()
-
-    @cached_property
-    def payment_statuses(self):
-        return [self.payment_status]
-
 
 class EventDiscount(SubjectDiscount):
     registration = models.ForeignKey(EventRegistration, on_delete=models.CASCADE,
