@@ -1,35 +1,33 @@
 from datetime import datetime, timedelta
 
-from django.core.urlresolvers import reverse_lazy as reverse
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
+from django.urls import reverse_lazy as reverse
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
 from djangocms_text_ckeditor.fields import HTMLField
 
 from .startend import StartEndMixin
-from .subjects import Subject, SubjectRegistration
+from .subjects import Subject, SubjectRegistrationParticipant
 
 
-def get_default_agenda():
-    return '<p>{}</p>'.format(_('instruction on OSH'))
-
-
-@python_2_unicode_compatible
 class JournalEntry(StartEndMixin, models.Model):
-    subject     = models.ForeignKey(Subject, verbose_name=_('subject'), editable=False,
-                                    related_name='journal_entries', on_delete=models.PROTECT)
-    date        = models.DateField(_('date'))
-    start       = models.TimeField(_('start time'), blank=True, null=True)
-    end         = models.TimeField(_('end time'), blank=True, null=True)
-    agenda      = HTMLField(_('session agenda'), default=get_default_agenda)
-    registrations = models.ManyToManyField(SubjectRegistration, verbose_name=_('participants'), blank=True,
-                                           related_name='journal_entries')
+    subject = models.ForeignKey(Subject, editable=False, on_delete=models.PROTECT,
+                                related_name='journal_entries', verbose_name=_('subject'))
+    date = models.DateField(_('date'))
+    start = models.TimeField(_('start time'), blank=True, null=True)
+    end = models.TimeField(_('end time'), blank=True, null=True)
+    agenda = HTMLField(_('session agenda'), default='')
+    participants = models.ManyToManyField(SubjectRegistrationParticipant, blank=True,
+                                          related_name='journal_entries', verbose_name=_('participants'))
+    participants_instructed = models.ManyToManyField(
+        SubjectRegistrationParticipant, blank=True, related_name='instructed',
+        verbose_name=_('participants instructed about safety and internal rules'),
+    )
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('date', 'start', 'end')
-        verbose_name        = _('journal entry')
+        app_label = 'leprikon'
+        ordering = ('date', 'start', 'end')
+        verbose_name = _('journal entry')
         verbose_name_plural = _('journal entries')
 
     def __str__(self):
@@ -43,31 +41,35 @@ class JournalEntry(StartEndMixin, models.Model):
     def datetime_start(self):
         try:
             return datetime.combine(self.date, self.start)
-        except:
+        except TypeError:
             return None
 
     @cached_property
     def datetime_end(self):
         try:
             return datetime.combine(self.date, self.end)
-        except:
+        except TypeError:
             return None
 
     @cached_property
     def duration(self):
         try:
             return self.datetime_end - self.datetime_start
-        except:
+        except TypeError:
             return timedelta()
     duration.short_description = _('duration')
 
     @cached_property
-    def all_registrations(self):
-        return list(self.registrations.all())
+    def all_participants(self):
+        return list(self.participants.all())
 
     @cached_property
-    def all_registrations_idset(self):
-        return set(r.id for r in self.all_registrations)
+    def all_participants_instructed(self):
+        return list(self.participants_instructed.all())
+
+    @cached_property
+    def all_participants_idset(self):
+        return set(r.id for r in self.all_participants)
 
     @cached_property
     def all_leader_entries(self):
@@ -91,12 +93,9 @@ class JournalEntry(StartEndMixin, models.Model):
             if le.timesheet.leader not in self.subject.all_leaders
         )
 
-    @property
-    def timesheets(self):
-        from .timesheets import Timesheet
-        return Timesheet.objects.by_date(self.start).filter(
-            leader__in = self.all_leaders + self.all_alternates,
-        )
+    @cached_property
+    def affects_submitted_timesheets(self):
+        return self.leader_entries.filter(timesheet__submitted=True).exists()
 
     def save(self, *args, **kwargs):
         if self.end is None:
@@ -110,20 +109,19 @@ class JournalEntry(StartEndMixin, models.Model):
         return reverse('leprikon:journalentry_delete', args=(self.id,))
 
 
-@python_2_unicode_compatible
 class JournalLeaderEntry(StartEndMixin, models.Model):
-    journal_entry = models.ForeignKey(JournalEntry, verbose_name=_('journal entry'),
-                                      related_name='leader_entries', editable=False)
-    timesheet   = models.ForeignKey('leprikon.Timesheet', verbose_name=_('timesheet'), related_name='journal_entries',
-                                    editable=False, on_delete=models.PROTECT)
-    start       = models.TimeField(_('start time'))
-    end         = models.TimeField(_('end time'))
+    journal_entry = models.ForeignKey(JournalEntry, editable=False, on_delete=models.CASCADE,
+                                      related_name='leader_entries', verbose_name=_('journal entry'))
+    timesheet = models.ForeignKey('leprikon.Timesheet', editable=False, on_delete=models.PROTECT,
+                                  related_name='journal_entries', verbose_name=_('timesheet'))
+    start = models.TimeField(_('start time'))
+    end = models.TimeField(_('end time'))
 
     class Meta:
-        app_label           = 'leprikon'
-        verbose_name        = _('journal leader entry')
+        app_label = 'leprikon'
+        verbose_name = _('journal leader entry')
         verbose_name_plural = _('journal leader entries')
-        unique_together     = (('journal_entry', 'timesheet'),)
+        unique_together = (('journal_entry', 'timesheet'),)
 
     def __str__(self):
         return '{subject_name}, {date}, {duration}'.format(
